# Roadmap

## Current State

- SKLX is a Python library designed to provide an interface for building and training machine learning models.
- It currently lacks support for some features found in popular libraries like [skorch](https://github.com/skorch-dev/skorch).

## Future Roadmap

1. Completing Feature Parity with [Skorch](https://github.com/skorch-dev/skorch)
   1. ~Pipeline Support~
   2. ~Grid Search Support~
   3. Learning Rate Scheduler
   4. Scoring
   5. Early Stopping
   6. Checkpointing
   7. Parameter Freezing
   8. Progress Bar
